@@ -7,4 +7,4 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 
 from .handle import Handle
-from .handle import Reader
+from .reader import Reader
