@@ -5,7 +5,7 @@ def load(h):
 
     def wrapped(h):
 
-        indicatorOfParameter = h.get('indicatorOfParameter')
+        indicatorOfParameter = h.get_l('indicatorOfParameter')
 
         if indicatorOfParameter == 1:
             return 'test'
