@@ -5,8 +5,8 @@ def load(h):
 
     def wrapped(h):
 
-        subCentre = h.get('subCentre')
-        grib2LocalSectionNumber = h.get('grib2LocalSectionNumber')
+        subCentre = h.get_l('subCentre')
+        grib2LocalSectionNumber = h.get_l('grib2LocalSectionNumber')
 
         if subCentre == 98 and grib2LocalSectionNumber == 28:
             return 'cosmo-leps'
