@@ -5,18 +5,19 @@ def load(h):
 
     def wrapped(h):
 
-        discipline = h.get('discipline')
-        parameterCategory = h.get('parameterCategory')
-        parameterNumber = h.get('parameterNumber')
-        stepType = h.get('stepType')
-
-        if discipline == 0 and parameterCategory == 1 and parameterNumber == 10 and stepType == "accum":
-            return 'kg m**-2'
-
-        if discipline == 0 and parameterCategory == 1 and parameterNumber == 9 and stepType == "accum":
-            return 'kg m**-2'
+        discipline = h.get_l('discipline')
+        parameterCategory = h.get_l('parameterCategory')
+        parameterNumber = h.get_l('parameterNumber')
 
         if discipline == 0 and parameterCategory == 7 and parameterNumber == 6:
             return 'm**2 s**-2'
 
+        stepType = h.get_s('stepType')
+
+        if discipline == 0 and parameterCategory == 1 and parameterNumber == 9 and stepType == "accum":
+            return 'kg m**-2'
+
+        if discipline == 0 and parameterCategory == 1 and parameterNumber == 10 and stepType == "accum":
+            return 'kg m**-2'
+
     return wrapped
